import { Construct, IResource, Resource } from '@aws-cdk/cdk';
export interface INamespace extends IResource {
    /**
     * A name for the Namespace.
     */
    readonly namespaceName: string;
    /**
     * Namespace Id for the Namespace.
     */
    readonly namespaceId: string;
    /**
     * Namespace ARN for the Namespace.
     */
    readonly namespaceArn: string;
    /**
     * Type of Namespace
     */
    readonly type: NamespaceType;
    /**
     * Export the namespace properties
     */
    export(): NamespaceImportProps;
}
export interface BaseNamespaceProps {
    /**
     * A name for the Namespace.
     */
    readonly name: string;
    /**
     * A description of the Namespace.
     *
     * @default none
     */
    readonly description?: string;
}
export interface NamespaceImportProps {
    /**
     * A name for the Namespace.
     */
    readonly namespaceName: string;
    /**
     * Namespace Id for the Namespace.
     */
    readonly namespaceId: string;
    /**
     * Namespace ARN for the Namespace.
     */
    readonly namespaceArn: string;
    /**
     * Type of Namespace. Valid values: HTTP, DNS_PUBLIC, or DNS_PRIVATE
     */
    readonly type: NamespaceType;
}
export declare enum NamespaceType {
    /**
     * Choose this option if you want your application to use only API calls to discover registered instances.
     */
    Http = "HTTP",
    /**
     * Choose this option if you want your application to be able to discover instances using either API calls or using
     * DNS queries in a VPC.
     */
    DnsPrivate = "DNS_PRIVATE",
    /**
     * Choose this option if you want your application to be able to discover instances using either API calls or using
     * public DNS queries. You aren't required to use both methods.
     */
    DnsPublic = "DNS_PUBLIC"
}
export declare abstract class NamespaceBase extends Resource implements INamespace {
    abstract readonly namespaceId: string;
    abstract readonly namespaceArn: string;
    abstract readonly namespaceName: string;
    abstract readonly type: NamespaceType;
    export(): NamespaceImportProps;
}
/**
 * Static Namespace class
 */
export declare class Namespace {
    /**
     * Import a namespace
     */
    static import(scope: Construct, id: string, props: NamespaceImportProps): INamespace;
    private constructor();
}
